DataflowError

Enum DataflowError 

pub enum DataflowError<N, E, L> {
    UnknownSeed(N),
    ContinuationMismatch {
        changed: ContinuationFingerprint,
        expected: ValueFingerprint,
        actual: ValueFingerprint,
    },
    BudgetExceeded {
        kind: BudgetKind,
        limit: usize,
        attempted: usize,
        node: Option<N>,
        edge: Option<E>,
        location: L,
        target_location: Option<L>,
    },
    NodeFailure {
        failure: DataflowFailure,
        node: N,
        location: L,
    },
    EdgeFailure {
        failure: DataflowFailure,
        edge: E,
        location: L,
        target_location: L,
    },
}
A located fixpoint refusal.

Variants



UnknownSeed(N)

A seed names no node in the immutable graph.



ContinuationMismatch

A continuation was presented to inputs other than the ones it captured.

Fields

changed: ContinuationFingerprint

Fingerprint category that changed.

expected: ValueFingerprint

Fingerprint captured by the continuation.

actual: ValueFingerprint

Fingerprint supplied while resuming.



BudgetExceeded

A declared budget was exhausted at a node or edge.

Fields

kind: BudgetKind

Exhausted core budget class.

limit: usize

Configured limit.

attempted: usize

Units that the rejected operation would consume.

node: Option<N>

Node active at the refusal, when applicable.

edge: Option<E>

Edge active at the refusal, when applicable.

location: L

Source/artifact location of node, or the edge predecessor.

target_location: Option<L>

Edge successor location, when the refusal occurred on an edge.



NodeFailure

An admitted transfer violated its contract at a precise node.

Fields

failure: DataflowFailure

Failed operation.

node: N

Stable node identity.

location: L

Consumer-neutral node location.



EdgeFailure

A lattice join violated its contract while propagating a precise edge.

Fields

failure: DataflowFailure

Failed operation.

edge: E

Stable edge identity.

location: L

Edge predecessor location in propagation order.

target_location: L

Edge successor location in propagation order.