pub struct AdmittedTransfer<P> { /* private fields */ }Expand description
A transfer policy that passed the public dataflow law suite.
Implementations
Sourceimpl<P> AdmittedTransfer<P>
impl<P> AdmittedTransfer<P>
Sourcepub fn admit<S>(policy: P, samples: &[S]) -> Result<Self, LawViolation>where
S: JoinSemilattice,
P: TransferPolicy<S>,
pub fn admit<S>(policy: P, samples: &[S]) -> Result<Self, LawViolation>where
S: JoinSemilattice,
P: TransferPolicy<S>,
Admits a policy only when both lattice and transfer laws hold.
Sourcepub const fn fingerprint(&self) -> ValueFingerprint
pub const fn fingerprint(&self) -> ValueFingerprint
Returns the stable identity captured at admission.
Sourcepub const fn policy_size(&self) -> usize
pub const fn policy_size(&self) -> usize
Returns the retained policy size captured at admission.
Sourcepub fn transfer<S>(&self, state: &S) -> Swhere
P: TransferPolicy<S>,
pub fn transfer<S>(&self, state: &S) -> Swhere
P: TransferPolicy<S>,
Applies the admitted policy.