JoinSemilattice

Trait JoinSemilattice 

pub trait JoinSemilattice:
    Clone
    + Eq
    + StateSize {
    // Required methods
    fn bottom(&self) -> Self;
    fn join(&self, other: &Self) -> Self;
    fn less_equal(&self, other: &Self) -> bool;
}
A join semilattice with a least element.

Implementations are admitted only after LawSuite checks their observable laws over the representative states supplied by the consumer.

Required Methods

fn bottom(&self) -> Self

Returns the least element.

fn join(&self, other: &Self) -> Self

Returns the least upper bound of self and other.

fn less_equal(&self, other: &Self) -> bool

Reports the semilattice partial order.

Dyn Compatibility

This trait is not dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors