LocatedGraphAdapter

Trait LocatedGraphAdapter 

pub trait LocatedGraphAdapter {
    type NodeId: Clone + Hash + Ord;
    type EdgeId: Clone + Hash + Ord;
    type Location: Hash + Ord;
    type Class: Hash + Ord;

    // Required methods
    fn nodes(&self) -> Vec<NodeSpec<Self::NodeId, Self::Location>>;
    fn edges(&self) -> Vec<EdgeSpec<Self::EdgeId, Self::NodeId, Self::Class>>;

    // Provided method
    fn build_graph(&self) -> AdapterBuildResult<Self> { ... }
}
Projects an external located representation into neutral graph declarations.

Implement this trait on a small adapter that borrows an external located-code object. Only the returned identities, locations, classes, and directions are retained by DataflowGraph.

Required Associated Types

type NodeId: Clone + Hash + Ord

Stable node identity.

type EdgeId: Clone + Hash + Ord

Stable edge identity.

type Location: Hash + Ord

Neutral location value.

type Class: Hash + Ord

Consumer edge-class extension.

Required Methods

fn nodes(&self) -> Vec<NodeSpec<Self::NodeId, Self::Location>>

Produces located node declarations.

fn edges(&self) -> Vec<EdgeSpec<Self::EdgeId, Self::NodeId, Self::Class>>

Produces directed edge declarations.

Provided Methods

fn build_graph(&self) -> AdapterBuildResult<Self>

Validates and freezes the projected graph.

Dyn Compatibility

This trait is dyn compatible.

In older versions of Rust, dyn compatibility was called "object safety".

Implementors