ProjectorQualification

Enum ProjectorQualification 

pub enum ProjectorQualification {
    TrustedNative {
        source: QualifiedSourceClosure,
        policy: ContentId,
    },
    ClosedWasm {
        module: ContentId,
        policy: ContentId,
        runtime: QualifiedRuntime,
        imports: DeterministicImportManifest,
        admission: ContentId,
    },
}
One of the two projector admission routes allowed by the roadmap.

Variants



TrustedNative

Exact reviewed native code and dependency closure.

Fields

source: QualifiedSourceClosure

Qualified source closure.

policy: ContentId

Policy identity reviewed with that source.



ClosedWasm

Closed wasm module with verified imports and runtime behavior.

Fields

module: ContentId

Exact semantic module identity.

policy: ContentId

Policy identity used for admission.

runtime: QualifiedRuntime

Qualified runtime and semantics.

imports: DeterministicImportManifest

Verified complete import manifest.

admission: ContentId

Admission evidence identity.