pub struct Observation<K> { /* private fields */ }Expand description
One dependency observation captured by a query frame.
Implementations
Sourceimpl<K> Observation<K>
impl<K> Observation<K>
Sourcepub fn new(
key: K,
kind: ObservationKind,
revision: Revision,
fingerprint: Option<ValueFingerprint>,
) -> Self
pub fn new( key: K, kind: ObservationKind, revision: Revision, fingerprint: Option<ValueFingerprint>, ) -> Self
Creates an observation from a key, kind, revision, and optional value fingerprint.
Sourcepub fn read(key: K, revision: Revision, fingerprint: ValueFingerprint) -> Self
pub fn read(key: K, revision: Revision, fingerprint: ValueFingerprint) -> Self
Creates a query-read observation.
Sourcepub fn kind(&self) -> &ObservationKind
pub fn kind(&self) -> &ObservationKind
Returns the observation kind.
Sourcepub fn fingerprint(&self) -> Option<ValueFingerprint>
pub fn fingerprint(&self) -> Option<ValueFingerprint>
Returns the captured value fingerprint when this observation has one.