pub struct DataflowExplanation<N, E> { /* private fields */ }Expand description
A bounded explanation that cannot masquerade as complete after truncation.
Implementations
Sourceimpl<N, E> DataflowExplanation<N, E>
impl<N, E> DataflowExplanation<N, E>
Sourcepub fn predecessors(&self) -> &[CausalPredecessor<N, E>]
pub fn predecessors(&self) -> &[CausalPredecessor<N, E>]
Returns the retained causal predecessors in deterministic discovery order.