pub struct ProjectionEngine<'a> { /* private fields */ }Expand description
Pure projection coordinator over a sealed world and federated closure.
Implementations
Sourceimpl<'a> ProjectionEngine<'a>
impl<'a> ProjectionEngine<'a>
Sourcepub fn new(
registry: &'a ProjectionRegistry,
shapes: &'a dyn ConfigShapeVerifier,
closure: &'a FederatedClosure,
) -> Self
pub fn new( registry: &'a ProjectionRegistry, shapes: &'a dyn ConfigShapeVerifier, closure: &'a FederatedClosure, ) -> Self
Binds the loaded registry, Shape verifier, and sealed closure.
Sourcepub fn project(
&self,
world: &ObservedWorld,
spec: &ProjectionSpec,
policy: &ProjectorPolicy,
qualification: Option<&ProjectorQualification>,
confinement: Option<ConfinementEvidence>,
) -> Result<ProjectionResult, ProjectionError>
pub fn project( &self, world: &ObservedWorld, spec: &ProjectionSpec, policy: &ProjectorPolicy, qualification: Option<&ProjectorQualification>, confinement: Option<ConfinementEvidence>, ) -> Result<ProjectionResult, ProjectionError>
Runs one qualified projection without acquiring observation or effects.